@@ -4,6 +4,7 @@
 import os
 import platform
 import shlex
+import string
 import subprocess
 import warnings
 from threading import Thread
@@ -22,7 +23,7 @@ class NmapTask(object):
 
     """
     NmapTask is a internal class used by process. Each time nmap
-    starts a new task during the scan, a new class will be instanciated.
+    starts a new task during the scan, a new class will be instantiated.
     Classes examples are: "Ping Scan", "NSE script", "DNS Resolve",..
     To each class an estimated time to complete is assigned and updated
     at least every second within the NmapProcess.
@@ -129,6 +130,9 @@ class NmapProcess(Thread):
                 "Supplied target list should be either a string or a list"
             )
 
+        for target in self.__nmap_targets:
+            self.__validate_target(target)
+
         self._nmap_options = set(options.split())
         if safe_mode and not self._nmap_options.isdisjoint(unsafe_opts):
             raise Exception(
@@ -215,7 +219,7 @@ class NmapProcess(Thread):
     def sudo_run(self, run_as="root"):
         """
         Public method enabling the library's user to run the scan with
-        priviledges via sudo. The sudo configuration should be set manually
+        privileges via sudo. The sudo configuration should be set manually
         on the local system otherwise sudo will prompt for a password.
         This method alters the command line by prefixing the sudo command to
         nmap and will then call self.run()
@@ -245,7 +249,7 @@ class NmapProcess(Thread):
     def sudo_run_background(self, run_as="root"):
         """
         Public method enabling the library's user to run in background a
-        nmap scan with priviledges via sudo.
+        nmap scan with privileges via sudo.
         The sudo configuration should be set manually on the local system
         otherwise sudo will prompt for a password.
         This method alters the command line by prefixing the sudo command to
@@ -480,6 +484,41 @@ class NmapProcess(Thread):
             cmdline += self.__nmap_targets  # already a list
         return cmdline
 
+    @staticmethod
+    def __validate_target(target):
+        """
+        Check if a provided target is valid. This function was created
+        in order to address CVE-2022-30284
+
+        See https://nmap.org/book/man-target-specification.html for all the
+        ways targets can be specified
+
+        This function verifies the following:
+
+        - matches the user specified target against a list of allowed chars
+        - check if dashes are used at the start or at the end of target
+
+        FQDN can contain dashes anywhere except at the beginning or end
+        This check also fixes/prevents CVE-2022-30284, which depends on being
+        able to pass options such as --script as a target
+
+        :return: False if target contains forbidden characters
+        """
+        allowed_characters = frozenset(
+            string.ascii_letters + string.digits + "-.:/% "
+        )
+        if not set(target).issubset(allowed_characters):
+            raise Exception(
+                "Target '{}' contains invalid characters".format(target)
+            )
+        elif target.startswith("-") or target.endswith("-"):
+            raise Exception(
+                "Target '{}' cannot begin or end with a dash ('-')".format(
+                    target
+                )
+            )
+        return True
+
     @property
     def command(self):
         """
